package com.ailanyin.admin.controller;

import com.ailanyin.admin.service.HxProductCompletionOverviewService;
import com.ailanyin.common.result.AjaxResult;
import com.ailanyin.common.result.CommonPage;
import com.ailanyin.common.utils.EmptyUtil;
import com.ailanyin.common.utils.ExcelUtil;
import com.ailanyin.model.HxProductCompletionOverview;
import com.github.pagehelper.PageHelper;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import java.util.ArrayList;
import java.util.List;

/**
 * @author ailanyin
 * @version 1.0
 * @since 2021/12/7 0007 上午 10:28
 */
@RestController
@RequestMapping("/hx/productCompletion")
@Api(tags = "红峡交付产品完成概况管理")
public class HxProductCompletionOverviewController {

    @Autowired
    private HxProductCompletionOverviewService hxProductCompletionOverviewService;

    //@PreAuthorize("hasAuthority('hx:productCompletion:list')")
    @GetMapping("/list")
    @ApiOperation(value = "红峡交付产品完成概况列表")
    public CommonPage list(HxProductCompletionOverview completionOverview,
                           @RequestParam(value = "pageSize", required = false) Integer pageSize,
                           @RequestParam(value = "pageNum", required = false) Integer pageNum) {

        if (EmptyUtil.isNotEmpty(pageSize) && EmptyUtil.isNotEmpty(pageNum)) {
            PageHelper.startPage(pageNum, pageSize);
        }
        List<HxProductCompletionOverview> list = hxProductCompletionOverviewService.selectHxProductCompletionOverviewList(completionOverview);
        return CommonPage.restPage(list);
    }

    @PostMapping("/importData")
    @ApiOperation(value = "导入Excel列表")
    //@PreAuthorize("hasAuthority('hx:productCompletion:import')")
    public AjaxResult importData(MultipartFile file) throws Exception {
        List<HxProductCompletionOverview> list = ExcelUtil.importExcel(file, HxProductCompletionOverview.class);
        hxProductCompletionOverviewService.importData(list);
        return AjaxResult.success();
    }

    @GetMapping("/importTemplate")
    @ApiOperation(value = "导出模板")
    //@PreAuthorize("hasAuthority('system:user:import')")
    public AjaxResult importTemplate() throws Exception {
        return AjaxResult.success(ExcelUtil.exportExcel(new ArrayList<>(), "交付产品完成概况表", "交付产品完成概况", HxProductCompletionOverview.class, "交付产品完成概况"));
    }

    //@PreAuthorize("hasAuthority('hx:dict:delete')")
    @DeleteMapping
    @ApiOperation(value = "删除红峡交付产品完成概况")
    public AjaxResult delHxProductCompletionOverview(@RequestParam(value = "id") Long id) {
        hxProductCompletionOverviewService.delHxProductCompletionOverviewById(id);
        return AjaxResult.success();
    }
}
