package com.ailanyin.admin.service;

import com.ailanyin.model.SysConfig;

import java.util.List;

/**
 * @author ailanyin
 * @version 1.0
 * @since 2021/10/15 0015 下午 16:44
 */
public interface SysConfigService {

    /**
     * 查询参数配置列表
     *
     * @param config 参数配置信息
     * @return 参数配置集合
     */
    List<SysConfig> selectConfigList(SysConfig config);

    /**
     * 加载参数缓存数据
     */
    void loadingConfigCache();

    /**
     * 根据键名查询参数配置信息
     *
     * @param configKey 参数键名
     * @return 参数键值
     */
    String selectConfigByKey(String configKey);

    /**
     * 查询参数配置信息
     *
     * @param configId 参数配置ID
     * @return SysConfig 参数配置信息
     */
    SysConfig selectConfigById(Long configId);

    /**
     * 新增参数配置
     *
     * @param config 参数配置信息
     */
    void addSysConfig(SysConfig config);

    /**
     * 校验参数键名是否唯一
     *
     * @param config 参数信息
     * @return 结果
     */
    boolean checkConfigKeyNotUnique(SysConfig config);

    /**
     * 修改参数配置
     *
     * @param config 参数配置信息
     */
    void updateSysConfig(SysConfig config);

    /**
     * 批量删除参数信息
     *
     * @param configIds 需要删除的参数ID
     */
    void deleteConfigByIds(Long[] configIds);
}
