package com.ailanyin.admin.service;

import com.ailanyin.model.SysPost;

import java.util.List;

/**
 * @author ailanyin
 * @version 1.0
 * @since 2021/10/15 0015 下午 14:43
 */
public interface SysPostService {

    /**
     * 增加岗位
     *
     * @param post post
     */
    void insertPost(SysPost post);

    /**
     * 校验岗位名称
     *
     * @param post 岗位信息
     * @return 结果
     */
    boolean checkPostNameNotUnique(SysPost post);

    /**
     * 校验岗位编码
     *
     * @param post 岗位信息
     * @return 结果
     */
    boolean checkPostCodeNotUnique(SysPost post);

    /**
     * 修改岗位
     *
     * @param post post
     */
    void updatePost(SysPost post);

    /**
     * 批量删除岗位
     *
     * @param postIds ids
     */
    void deletePostByIds(Long[] postIds);

    /**
     * 通过岗位ID查询岗位信息
     *
     * @param postId 岗位ID
     * @return 角色对象信息
     */
    SysPost selectPostById(Long postId);

    /**
     * 通过岗位ID查询岗位使用数量
     *
     * @param postId 岗位ID
     * @return 结果
     */
    int countUserPostById(Long postId);

    /**
     * 查询全部岗位
     *
     * @return 全部岗位集合
     */
    List<SysPost> selectPostAll();

    /**
     * 根据用户ID获取岗位选择框列表
     *
     * @param userId 用户ID
     * @return 选中岗位ID列表
     */
    List<Integer> selectPostListByUserId(Long userId);

    /**
     * 查询岗位列表
     *
     * @param post 查询条件
     * @return List<SysPost>
     */
    List<SysPost> selectPostList(SysPost post);
}
