package com.ailanyin.admin.service;

import com.ailanyin.model.SysRole;
import com.ailanyin.model.SysUserRole;

import java.util.List;
import java.util.Set;

/**
 * @author ailanyin
 * @version 1.0
 * @since 2021/10/15 0015 下午 13:03
 */
public interface SysRoleService {

    /**
     * 新增角色
     *
     * @param role role
     */
    void insertRole(SysRole role);

    /**
     * 修改角色
     *
     * @param role role
     */
    void updateRole(SysRole role);

    /**
     * 校验角色名称是否不唯一
     *
     * @param role 角色信息
     * @return 结果
     */
    boolean checkRoleNameNotUnique(SysRole role);

    /**
     * 校验角色权限是否不唯一
     *
     * @param role 角色信息
     * @return 结果
     */
    boolean checkRoleKeyNotUnique(SysRole role);

    /**
     * 校验角色是否允许操作
     *
     * @param role 角色信息
     */
    void checkRoleAllowed(SysRole role);

    /**
     * 保存修改数据权限
     *
     * @param role role
     */
    void authDataScope(SysRole role);

    /**
     * 状态修改
     *
     * @param role role
     */
    void updateRoleStatus(SysRole role);

    /**
     * 批量删除角色
     *
     * @param roleIds 角色 ids
     */
    void deleteRoleByIds(Long[] roleIds);

    /**
     * 通过角色ID查询角色
     *
     * @param roleId 角色ID
     * @return 角色对象信息
     */
    SysRole selectRoleById(Long roleId);

    /**
     * 通过角色ID查询角色使用数量
     *
     * @param roleId 角色ID
     * @return 结果
     */
    int countUserRoleByRoleId(Long roleId);

    /**
     * 查询所有角色
     *
     * @return 所有角色
     */
    List<SysRole> selectRoleAll();

    /**
     * 批量选择授权用户角色
     *
     * @param roleId  角色ID
     * @param userIds 需要删除的用户数据ID
     */
    void insertAuthUsers(Long roleId, Long[] userIds);

    /**
     * 批量取消授权用户角色
     *
     * @param roleId  角色ID
     * @param userIds 需要取消授权的用户数据ID
     */
    void deleteAuthUsers(Long roleId, Long[] userIds);

    /**
     * 取消授权用户角色
     *
     * @param userRole userRole
     */
    void deleteAuthUser(SysUserRole userRole);

    /**
     * 查询角色列表
     *
     * @param role 查询条件
     * @return 角色集合
     */
    List<SysRole> selectRoleList(SysRole role);

    /**
     * 查询用户拥有的所有角色
     *
     * @param userId 用户 id
     * @return 角色列表
     */
    List<SysRole> selectRolesByUserId(Long userId);

    /**
     * 根据用户ID获取角色选择框列表
     *
     * @param userId 用户ID
     * @return 选中角色ID列表
     */
    List<Integer> selectRoleListByUserId(Long userId);

    /**
     * 根据用户ID查询角色权限
     *
     * @param userId 用户ID
     * @return 权限列表
     */
    Set<String> selectRolePermissionByUserId(Long userId);

    /**
     * 校验角色是否有数据权限
     *
     * @param roleId 角色id
     */
    void checkRoleDataScope(Long roleId);

    /**
     * 重置超级管理员权限
     */
    void refreshRole();

}
