package com.ailanyin.admin.service;

import com.ailanyin.model.SysUser;
import org.springframework.web.multipart.MultipartFile;


import java.util.List;

/**
 * @author ailanyin
 * @version 1.0
 * @since 2021/10/15 0015 上午 11:16
 */
public interface SysUserService {

    /**
     * 获取当前登录的用户信息
     *
     * @return sysUser
     */
    SysUser getCurrentUser();

    /**
     * 根据条件分页查询已分配用户角色列表
     *
     * @param user 查询条件
     * @return 用户集合
     */
    List<SysUser> selectAllocatedList(SysUser user);

    /**
     * 新增用户
     *
     * @param user user
     */
    void insertUser(SysUser user);

    /**
     * 校验用户名称是否不唯一
     *
     * @param userName 用户名称
     * @return 结果
     */
    boolean checkUserNameNotUnique(String userName);


    /**
     * 更新用户信息
     *
     * @param user user
     */
    void updateUser(SysUser user);

    /**
     * 校验用户是否允许操作
     *
     * @param user 用户信息
     */
    void checkUserAllowed(SysUser user);

    /**
     * 批量删除用户
     *
     * @param userIds ids
     */
    void deleteUserByIds(Long[] userIds);

    /**
     * 重置密码
     *
     * @param user user
     */
    void resetPwd(SysUser user);

    /**
     * 修改状态
     *
     * @param user user
     */
    void updateUserStatus(SysUser user);

    /**
     * 通过 id 查询
     *
     * @param userId
     * @return
     */
    SysUser selectUserById(Long userId);

    /**
     * 用户授权角色
     *
     * @param userId 用户ID
     * @param roleIds 角色组
     */
    void insertUserAuth(Long userId, Long[] roleIds);

    /**
     * 校验用户是否有数据权限
     *
     * @param userId 用户id
     */
    void checkUserDataScope(Long userId);

    /**
     * 根据条件分页查询用户列表
     *
     * @param user 用户信息
     * @return 用户信息集合信息
     */
    List<SysUser> selectUserList(SysUser user);

    /**
     * 根据条件分页查询未分配用户角色列表
     *
     * @param user 用户信息
     * @return 用户信息集合信息
     */
    List<SysUser> selectUnallocatedList(SysUser user);

    /**
     * 通过用户名查询用户
     *
     * @param userName 用户名
     * @return 用户对象信息
     */
    SysUser selectUserByUserName(String userName);

    /**
     * 导入用户列表
     *
     * @param list 用户列表
     * @param updateSupport 是否更新已经存在的数量
     */
    void importData(List<SysUser> list, boolean updateSupport);

    /**
     * 已删除用户列表
     *
     * @param user user
     * @return list
     */
    List<SysUser> selectDeleteUserList(SysUser user);

    /**
     * 恢复已删除的用户
     *
     * @param ids ids
     */
    void recoveryDeleteUser(List<Long> ids);

    /**
     * 彻底删除用户
     *
     * @param ids ids
     */
    void realDeleteUser(List<Long> ids);

    /**
     * 根据 username 查询用户所属角色组
     *
     * @param userName 用户名
     * @return 结果
     */
    String selectUserRoleGroup(String userName);

    /**
     * 根据用户ID查询用户所属岗位组
     *
     * @param userName 用户名
     * @return 结果
     */
    String selectUserPostGroup(String userName);

    /**
     * 用户自主修改基本信息
     *
     * @param user user
     */
    void updateProfile(SysUser user);

    /**
     * 用户自主修改密码
     *
     * @param oldPassword 旧密码
     * @param newPassword 新密码
     */
    void updatePwd(String oldPassword, String newPassword);

    /**
     * 更新头像
     *
     * @param file file
     */
    void updateAvatar(MultipartFile file);
}
