package com.ailanyin.admin.service.impl;

import com.ailanyin.admin.service.HxChargeQuantityService;
import com.ailanyin.common.exception.Asserts;
import com.ailanyin.common.utils.BigDecimalUtil;
import com.ailanyin.common.utils.StringUtil;
import com.ailanyin.mapper.HxChargeQuantityMapper;
import com.ailanyin.model.HxChargeQuantity;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.Date;
import java.util.List;

/**
 * @author ailanyin
 * @version 1.0
 * @since 2021/12/6 0006 下午 14:15
 */
@Service
public class HxChargeQuantityServiceImpl implements HxChargeQuantityService {

    @Resource
    private HxChargeQuantityMapper hxChargeQuantityMapper;

    /**
     * 新增装药量
     *
     * @param hxChargeQuantity 装药量
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public void addHxChargeQuantity(HxChargeQuantity hxChargeQuantity) {

        if (checkMonthIsExist(hxChargeQuantity.getMonth())) {
            Asserts.fail("【"+hxChargeQuantity.getMonth()+"】已经存在！");
        }

        hxChargeQuantity.setCreateTime(new Date());
        hxChargeQuantity.setTargetCompletionRate(getChargeQuantityRate(hxChargeQuantity));
        hxChargeQuantityMapper.addHxChargeQuantity(hxChargeQuantity);
    }

    /**
     * 修改装药量
     *
     * @param hxChargeQuantity 装药量
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public void updateHxChargeQuantity(HxChargeQuantity hxChargeQuantity) {
        hxChargeQuantity.setTargetCompletionRate(getChargeQuantityRate(hxChargeQuantity));
        hxChargeQuantityMapper.updateHxChargeQuantity(hxChargeQuantity);
    }

    /**
     * 获取装药量列表
     *
     * @param hxChargeQuantity hxChargeQuantity
     * @return list
     */
    @Override
    public List<HxChargeQuantity> selectHxChargeQuantityList(HxChargeQuantity hxChargeQuantity) {
        return hxChargeQuantityMapper.selectHxChargeQuantityList(hxChargeQuantity);
    }

    private boolean checkMonthIsExist(String month) {
        return hxChargeQuantityMapper.checkMonthIsExist(month) > 0;
    }

    private String getChargeQuantityRate(HxChargeQuantity hxChargeQuantity) {
        // eg: 67.0
        String rate = String.valueOf(
                BigDecimalUtil.div(
                        Double.valueOf(hxChargeQuantity.getActualQuantity()),
                        Double.valueOf(hxChargeQuantity.getTargetQuantity()),2
                ) * 100
        );
        // 67.0 -> 67
        return rate.substring(0,rate.length() - 2);
    }
}
