package com.ailanyin.admin.service.impl;

import com.ailanyin.admin.service.HxDangerousPlaceService;
import com.ailanyin.common.utils.EmptyUtil;
import com.ailanyin.mapper.HxDangerousPlaceMapper;
import com.ailanyin.model.HxDangerousPlace;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

/**
 * @author ailanyin
 * @version 1.0
 * @since 2021/12/9 0009 下午 15:32
 */
@Service
@Transactional(rollbackFor = Exception.class)
public class HxDangerousPlaceServiceImpl implements HxDangerousPlaceService {

    @Value("${hxDict.placeLevelParentId}")
    private String placeLevelParentId;

    @Resource
    private HxDangerousPlaceMapper hxDangerousPlaceMapper;

    /**
     * 查询危险场所
     *
     * @param hxDangerousPlace hxDangerousPlace
     * @return list
     */
    @Override
    public List<HxDangerousPlace> selectHxDangerousPlaceList(HxDangerousPlace hxDangerousPlace) {
        return hxDangerousPlaceMapper.selectHxDangerousPlaceList(hxDangerousPlace);
    }

    /**
     * 导入数据
     *
     * @param list list
     */
    @Override
    public void importData(List<HxDangerousPlace> list) {
        list.forEach(hxDangerousPlace -> {
            if (EmptyUtil.isNotEmpty(hxDangerousPlace.getPlaceName())) {

                // 存在  更新
                if (checkNameIsExist(hxDangerousPlace.getPlaceName())) {
                    hxDangerousPlaceMapper.updateByNameSelective(hxDangerousPlace);
                }
                // 新增
                else {
                    hxDangerousPlaceMapper.insertSelective(hxDangerousPlace);
                }
            }
        });
    }


    /**
     * 获取大屏
     *
     * @return map
     * */
    @Override
    public List<Map>  getDangerPlaceBigPic() {
        return hxDangerousPlaceMapper.selectSumByType(placeLevelParentId);
    }

    /**
     * 检查名称是否存在
     *
     * @param placeName name
     * @return 是/否
     */
    private boolean checkNameIsExist(String placeName) {
        return hxDangerousPlaceMapper.checkNameIsExist(placeName) > 0;
    }
}
