package com.ailanyin.admin.service.impl;

import com.ailanyin.admin.service.HxDangerousPointService;
import com.ailanyin.common.utils.EmptyUtil;
import com.ailanyin.mapper.HxDangerousPointMapper;
import com.ailanyin.mapper.HxDangerousSourceMapper;
import com.ailanyin.mapper.HxDictMapper;
import com.ailanyin.model.HxDangerousPoint;
import com.ailanyin.model.HxDangerousSource;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.*;

/**
 * @author ailanyin
 * @version 1.0
 * @since 2021/12/8 0008 下午 15:44
 */
@Service
@Transactional(rollbackFor = Exception.class)
public class HxDangerousPointServiceImpl implements HxDangerousPointService {

    @Value("${hxDict.deptParentId}")
    private String deptParentId;
    @Value("${hxDict.pointLevelParentId}")
    private String pointLevelParentId;
    @Value("${hxDict.sourceLevelParentId}")
    private String sourceLevelParentId;

    @Resource
    private HxDangerousPointMapper hxDangerousPointMapper;
    @Resource
    private HxDictMapper hxDictMapper;
    @Resource
    private HxDangerousSourceMapper hxDangerousSourceMapper;


    /**
     * 查询危险点列表
     *
     * @param hxDangerousPoint hxDangerousPoint
     * @return list
     */
    @Override
    public List<HxDangerousPoint> selectHxDangerousPointList(HxDangerousPoint hxDangerousPoint) {
        return hxDangerousPointMapper.selectHxDangerousPointList(hxDangerousPoint);
    }

    /**
     * 导入数据
     *
     * @param list list
     */
    @Override
    public void importData(List<HxDangerousPoint> list) {
        list.forEach(hxDangerousPoint -> {
            if (EmptyUtil.isNotEmpty(hxDangerousPoint.getPointName())) {
                hxDangerousPoint.setCreateTime(new Date());
                hxDangerousPointMapper.insertSelective(hxDangerousPoint);
            }
        });
    }

    /**
     * 获取大图
     *
     * @return map
     */
    @Override
    public Map getDangerPointBigPic() {
        Map<String,Object> returnMap = new LinkedHashMap<>(4);
        //All 危险源字典
        List<String> allDept = hxDictMapper.selectNameListByParentId(deptParentId);

        allDept.forEach(dept -> {
            returnMap.put(dept,hxDangerousPointMapper.selectAllLevelNumByDept(dept,pointLevelParentId));
        });
        returnMap.put("allLevel",hxDictMapper.selectNameListByParentId(pointLevelParentId));
        return returnMap;
    }

    /**
     * 中间危险点地图
     *
     * @return map
     */
    @Override
    public Map getDangerousMapBigPic() {
        Map returnMap = new HashMap(5);
        //危险点list
        List<HxDangerousPoint> points = hxDangerousPointMapper.selectHxDangerousPointList(new HxDangerousPoint());
        //危险源list
        //List<HxDangerousSource> sources = hxDangerousSourceMapper.selectHxDangerousSourceList(new HxDangerousSource());
        returnMap.put("pointLevelCount",hxDangerousPointMapper.selectAllLevelNumByDept(null,pointLevelParentId));
        returnMap.put("sourceLevelCount",hxDangerousSourceMapper.selectAllLevelNumByDept(null,sourceLevelParentId));
        returnMap.put("points",points);
        return returnMap;
    }
}
