package com.ailanyin.admin.service.impl;

import com.ailanyin.admin.service.HxDangerousSourceService;
import com.ailanyin.common.utils.EmptyUtil;
import com.ailanyin.mapper.HxDangerousSourceMapper;
import com.ailanyin.mapper.HxDictMapper;
import com.ailanyin.model.HxDangerousSource;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.*;

/**
 * @author ailanyin
 * @version 1.0
 * @since 2021/12/8 0008 下午 16:10
 */
@Service
public class HxDangerousSourceServiceImpl implements HxDangerousSourceService {

    @Value("${hxDict.deptParentId}")
    private String deptParentId;
    @Value("${hxDict.sourceLevelParentId}")
    private String sourceLevelParentId;

    @Resource
    private HxDangerousSourceMapper hxDangerousSourceMapper;
    @Resource
    private HxDictMapper hxDictMapper;


    /**
     * 查询危险源列表
     *
     * @param hxDangerousSource hxDangerousSource
     * @return list
     */
    @Override
    public List<HxDangerousSource> selectHxDangerousSourceList(HxDangerousSource hxDangerousSource) {
        return hxDangerousSourceMapper.selectHxDangerousSourceList(hxDangerousSource);
    }

    /**
     * 导入数据
     *
     * @param list list
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public void importData(List<HxDangerousSource> list) {
        list.forEach(hxDangerousSource -> {
            if (EmptyUtil.isNotEmpty(hxDangerousSource.getSourceName())) {
                hxDangerousSource.setCreateTime(new Date());
                hxDangerousSourceMapper.insertSelective(hxDangerousSource);
            }
        });
    }

    /**
     * 获取大图
     *
     * @return map
     */
    @Override
    public Map getDangerSourceBigPic() {
        Map<String,Object> returnMap = new LinkedHashMap<>(4);
        //All 危险源字典
        List<String> allDept = hxDictMapper.selectNameListByParentId(deptParentId);
        for (String dept : allDept) {
            returnMap.put(dept,hxDangerousSourceMapper.selectAllLevelNumByDept(dept,sourceLevelParentId));
        }
        returnMap.put("allLevel",hxDictMapper.selectNameListByParentId(sourceLevelParentId));
        return returnMap;
    }
}
