package com.ailanyin.admin.service.impl;

import com.ailanyin.admin.service.HxDangerousWorkService;
import com.ailanyin.common.utils.DateUtil;
import com.ailanyin.common.utils.EmptyUtil;
import com.ailanyin.mapper.HxDangerousWorkMapper;
import com.ailanyin.model.HxDangerousWork;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author ailanyin
 * @version 1.0
 * @since 2021/12/8 0008 下午 17:44
 */
@Service
@Transactional(rollbackFor = Exception.class)
public class HxDangerousWorkServiceImpl implements HxDangerousWorkService {

    @Resource
    private HxDangerousWorkMapper hxDangerousWorkMapper;

    private static final String WEEK = "1";
    private static final String MONTH = "2";

    /**
     * 查询危险作业列表
     *
     * @param hxDangerousWork hxDangerousWork
     * @return list
     */
    @Override
    public List<HxDangerousWork> selectHxDangerousWorkList(HxDangerousWork hxDangerousWork) {
        return hxDangerousWorkMapper.selectHxDangerousWorkList(hxDangerousWork);
    }

    /**
     * 导入
     *
     * @param list list
     */
    @Override
    public void importData(List<HxDangerousWork> list) {
        list.forEach(hxDangerousWork -> {
            if (EmptyUtil.isNotEmpty(hxDangerousWork.getWorkContent())) {
                hxDangerousWork.setCreateTime(new Date());
                hxDangerousWorkMapper.insertSelective(hxDangerousWork);
            }
        });
    }

    /**
     * 获取大图
     *
     * @param type 类型 1=周 2=月
     * @return map
     */
    @Override
    public List<HxDangerousWork> getDangerousWorkBigPic(String type) {
        return hxDangerousWorkMapper.selectByTime(handleDate(type));
    }

    private Map handleDate(String type) {
        Map<String,Object> map = new HashMap(2);
        if (WEEK.equals(type)) {
            map.put("start", DateUtil.getBeginDayOfWeek());
            map.put("end", DateUtil.getEndDayOfWeek());
        }

        if (MONTH.equals(type)) {
            map.put("start", DateUtil.getBeginDayOfMonth());
            map.put("end", DateUtil.getEndDayOfMonth());
        }

        return map;
    }
}
