package com.ailanyin.admin.service.impl;

import com.ailanyin.admin.service.HxDictService;
import com.ailanyin.common.exception.Asserts;
import com.ailanyin.mapper.HxDictMapper;
import com.ailanyin.model.HxDict;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.Date;
import java.util.List;

/**
 * @author ailanyin
 * @version 1.0
 * @since 2021/12/6 0006 上午 10:09
 */
@Service
public class HxDictServiceImpl implements HxDictService {

    @Resource
    private HxDictMapper hxDictMapper;


    /**
     * 获取红峡父节点列表
     *
     * @param hxDict 查询条件
     * @return list
     */
    @Override
    public List<HxDict> selectHxDictParentList(HxDict hxDict) {
        return hxDictMapper.selectHxDictParentList(hxDict);
    }

    /**
     * 添加红峡字典
     *
     * @param hxDict hxDict
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public void addHxDictType(HxDict hxDict) {

        if (checkNameIsExist(hxDict)) {
            Asserts.fail("名称【"+hxDict.getName()+"】已存在！");
        }

        hxDict.setCreateTime(new Date());
        hxDictMapper.addHxDictType(hxDict);
    }

    /**
     * 删除红峡字典
     *
     * @param hxDictId id
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public void delHxDictTypeById(Long hxDictId) {

        if (checkDictHasChild(hxDictId)) {
            Asserts.fail("存在子标签,禁止删除！");
        }
        hxDictMapper.delHxDictTypeById(hxDictId);
    }

    /**
     * 修改红峡字典
     *
     * @param hxDict hxDict
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public void updateHxDictType(HxDict hxDict) {
        if (checkNameIsExist(hxDict)) {
            Asserts.fail("名称【"+hxDict.getName()+"】已存在！");
        }
        hxDictMapper.updateHxDictType(hxDict);
    }

    private boolean checkNameIsExist(HxDict hxDict) {
        return hxDictMapper.checkNameIsExist(hxDict) > 0;
    }

    private boolean checkDictHasChild(Long hxDictId) {
        return hxDictMapper.checkDictHasChild(hxDictId) > 0;
    }
}
