package com.ailanyin.admin.service.impl;

import com.ailanyin.admin.service.HxHiddenDangerService;
import com.ailanyin.common.utils.BigDecimalUtil;
import com.ailanyin.common.utils.DateUtil;
import com.ailanyin.common.utils.EmptyUtil;
import com.ailanyin.common.utils.StringUtil;
import com.ailanyin.mapper.HxHiddenDangerMapper;
import com.ailanyin.model.HxHiddenDanger;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.*;

/**
 * @author ailanyin
 * @version 1.0
 * @since 2021/12/8 0008 下午 17:07
 */
@Service
@Transactional(rollbackFor = Exception.class)
public class HxHiddenDangerServiceImpl implements HxHiddenDangerService {

    @Value("${hxDict.alreadyUpdate}")
    private String alreadyUpdate;

    @Resource
    private HxHiddenDangerMapper hxHiddenDangerMapper;

    private static final String WORKSHOP = "1";
    private static final String GENERAL_FACTORY = "2";

    /**
     * 查询安全隐患列表
     *
     * @param hxHiddenDanger hxHiddenDanger
     * @return list
     */
    @Override
    public List<HxHiddenDanger> selectHxHiddenDangerList(HxHiddenDanger hxHiddenDanger) {
        return hxHiddenDangerMapper.selectHxHiddenDangerList(hxHiddenDanger);
    }

    /**
     * 导入
     *
     * @param list list
     */
    @Override
    public void importData(List<HxHiddenDanger> list) {
        list.forEach(hxHiddenDanger -> {
            if (EmptyUtil.isNotEmpty(hxHiddenDanger.getWorkshopName())) {
                hxHiddenDanger.setCreateTime(new Date());
                hxHiddenDangerMapper.insertSelective(hxHiddenDanger);
            }
        });
    }

    /**
     * 大图
     *
     * @param type 1车间/=2总厂
     * @return map
     */
    @Override
    public Map getHiddenDangerBigPic(String type) {
        Map<String,Object> map = new HashMap<>(3);
        if (WORKSHOP.equals(type)) {
            HxHiddenDanger hxHiddenDanger = new HxHiddenDanger();
            hxHiddenDanger.setMonth(String.valueOf(DateUtil.getNowYear()));
            map.put("list",hxHiddenDangerMapper.selectHxHiddenDangerList(hxHiddenDanger));
        }

        if (GENERAL_FACTORY.equals(type)) {
            List<Map> allCategoryAndCount = hxHiddenDangerMapper.getAllCategoryAndCount(DateUtil.getNowYear());
            Long measuresCount = hxHiddenDangerMapper.getCountByMeasures(alreadyUpdate,DateUtil.getNowYear());
            Long total = hxHiddenDangerMapper.getCountByMeasures(null, DateUtil.getNowYear());
            map.put("category",allCategoryAndCount);
            map.put("total",total);
            map.put("updateCate",BigDecimalUtil.calculateCompletionRate(
                    measuresCount.toString(),
                    total.toString()
            ));

        }
        return map;
    }

    /**
     * 安全隐患整改情况图
     *
     * @return list
     */
    @Override
    public List<Map> getWorkshopHiddenDangerBigPic() {
        List<Map> list = new ArrayList<>();
        //获取所有车间
        List<String> workshopList = hxHiddenDangerMapper.getAllWorkshopList();
        workshopList.forEach(workshop -> {
            Map map = new HashMap(3);
            Map countMap = hxHiddenDangerMapper.selectWorkShopDangerCount(workshop,alreadyUpdate);
            map.put("workShopName",workshop);
            map.put("count",countMap.get("TOTALCOUNT"));
            map.put("updateCount",countMap.get("UPDATECOUNT"));

            list.add(map);
        });
        return list;
    }

}
