package com.ailanyin.admin.service.impl;

import com.ailanyin.admin.service.HxProductCompletionOverviewService;
import com.ailanyin.common.utils.BigDecimalUtil;
import com.ailanyin.common.utils.EmptyUtil;
import com.ailanyin.mapper.HxProductCompletionOverviewMapper;
import com.ailanyin.model.HxProductCompletionOverview;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.Date;
import java.util.List;

/**
 * @author ailanyin
 * @version 1.0
 * @since 2021/12/7 0007 上午 10:30
 */
@Service
public class HxProductCompletionOverviewServiceImpl implements HxProductCompletionOverviewService {

    @Resource
    private HxProductCompletionOverviewMapper completionOverviewMapper;

    /**
     * 红峡交付产品完成概况列表
     *
     * @param completionOverview 查询条件
     * @return list
     */
    @Override
    public List<HxProductCompletionOverview> selectHxProductCompletionOverviewList(HxProductCompletionOverview completionOverview) {
        return completionOverviewMapper.selectHxProductCompletionOverviewList(completionOverview);
    }

    /**
     * Excel导入数据 不存在新增，存在更新
     *
     * @param list list
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public void importData(List<HxProductCompletionOverview> list) {
        list.forEach(this::handleData);
    }

    /**
     * 删除红峡交付产品完成概况
     *
     * @param id id
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public void delHxProductCompletionOverviewById(Long id) {
        completionOverviewMapper.delHxProductCompletionOverviewById(id);
    }

    /**
     * 数据库操作 不存在新增，存在更新
     */
    @Transactional(rollbackFor = Exception.class)
    public void handleData(HxProductCompletionOverview completionOverview) {
        if (EmptyUtil.isNotEmpty(completionOverview.getProductName())) {
            completionOverview.setCreateTime(new Date());
            // 计算完成率
            completionOverview.setCompletionRate(setCompletionRate(completionOverview));
            // 存在  更新
            if (checkProductIsExist(completionOverview.getProductName(),completionOverview.getMonth())) {
                completionOverviewMapper.updateByProductNameSelective(completionOverview);
            }
            // 不存在  新增
            else {
                completionOverviewMapper.insertSelective(completionOverview);
            }
        }
    }

    /**
     * 检查某产品完成率是否已经存在
     *
     * @param productName 产品名称
     * @return 是/否
     */
    private boolean checkProductIsExist(String productName,String month) {
        return completionOverviewMapper.checkProductIsExist(productName,month) > 0;
    }

    /**
     * 计算完成率
     * @param completionOverview completionOverview
     * @return 完成率
     */
    private String setCompletionRate(HxProductCompletionOverview completionOverview) {
        // eg: 67.0
        String rate = String.valueOf(
                BigDecimalUtil.div(
                        Double.valueOf(completionOverview.getActualDeliveryQuantity()),
                        Double.valueOf(completionOverview.getTargetDeliveryQuantity()),2
                ) * 100
        );
        // 67.0 -> 67
        return rate.substring(0,rate.length() - 2);
    }
}
