package com.ailanyin.admin.service.impl;

import com.ailanyin.admin.service.HxProductionResponsibilityService;
import com.ailanyin.common.utils.BigDecimalUtil;
import com.ailanyin.common.utils.EmptyUtil;
import com.ailanyin.mapper.HxProductionResponsibilityMapper;
import com.ailanyin.model.HxProductionResponsibility;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.Date;
import java.util.List;

/**
 * @author ailanyin
 * @version 1.0
 * @since 2021/12/8 0008 上午 9:06
 */
@Service
public class HxProductionResponsibilityServiceImpl implements HxProductionResponsibilityService {

    @Resource
    private HxProductionResponsibilityMapper responsibilityMapper;

    /**
     * 查询责任令列表
     *
     * @param productionResponsibility 条件
     * @return list
     */
    @Override
    public List<HxProductionResponsibility> selectHxProductionResponsibilityList(HxProductionResponsibility productionResponsibility) {
        return responsibilityMapper.selectHxProductionResponsibilityList(productionResponsibility);
    }

    /**
     * 导入数据
     *
     * @param list list
     */
    @Override
    public void importData(List<HxProductionResponsibility> list) {
        list.forEach(this::handleData);
    }

    /**
     * 数据库操作 不存在新增，存在更新
     */
    @Transactional(rollbackFor = Exception.class)
    public void handleData(HxProductionResponsibility productionResponsibility) {
        if (EmptyUtil.isNotEmpty(productionResponsibility.getTranslateName())) {
            productionResponsibility.setCreateTime(new Date());
            // 计算完成率
            productionResponsibility.setCompletionRate(setCompletionRate(productionResponsibility));
            // 存在  更新
            if (checkProductionIsExist(productionResponsibility.getTranslateName(),productionResponsibility.getMonth())) {
                responsibilityMapper.updateByNameAndMonthSelective(productionResponsibility);
            }
            // 不存在  新增
            else {
                responsibilityMapper.insertSelective(productionResponsibility);
            }
        }
    }

    /**
     * 检查某型号某月生产责任令是否已经存在
     *
     * @param translateName 项目名称
     * @param month 月份
     * @return 是/否
     */
    private boolean checkProductionIsExist(String translateName,String month) {
        return responsibilityMapper.checkProductionIsExist(translateName,month) > 0;
    }

    /**
     * 计算完成率
     * @param productionResponsibility productionResponsibility
     * @return 完成率
     */
    private String setCompletionRate(HxProductionResponsibility productionResponsibility) {
        // eg: 67.0
        String rate = String.valueOf(
                BigDecimalUtil.div(
                        Double.valueOf(productionResponsibility.getCompletedTaskNumber()),
                        Double.valueOf(productionResponsibility.getTargetTaskNumber()),2
                ) * 100
        );
        // 67.0 -> 67
        return rate.substring(0,rate.length() - 2);
    }
}
