package com.ailanyin.admin.service.impl;

import com.ailanyin.admin.service.HxQualityProblemService;
import com.ailanyin.common.exception.Asserts;
import com.ailanyin.common.utils.BigDecimalUtil;
import com.ailanyin.common.utils.EmptyUtil;
import com.ailanyin.mapper.HxQualityProblemMapper;
import com.ailanyin.model.HxQualityProblem;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.List;

/**
 * @author ailanyin
 * @version 1.0
 * @since 2021/12/10 0010 下午 15:42
 */
@Service
@Transactional(rollbackFor = Exception.class)
public class HxQualityProblemServiceImpl implements HxQualityProblemService {

    @Resource
    private HxQualityProblemMapper hxQualityProblemMapper;

    @Override
    public List<HxQualityProblem> selectHxQualityProblemList(HxQualityProblem hxQualityProblem) {
        return hxQualityProblemMapper.selectHxQualityProblemList(hxQualityProblem);
    }


    @Override
    public void importData(List<HxQualityProblem> list) {
        list.forEach(hxQualityProblem -> {
            if (EmptyUtil.isNotEmpty(hxQualityProblem.getName())) {
                if (EmptyUtil.isEmpty(hxQualityProblem.getDimension()) ||
                        // /3 因为 dimension = 1/2/3
                        hxQualityProblem.getDimension()/4 > 0) {
                    Asserts.fail("维度只能是1，2，3，输入错误！");
                }
                hxQualityProblem.setCompleteRate(BigDecimalUtil.calculateCompletionRate(
                        hxQualityProblem.getCompletedTotal(),
                        hxQualityProblem.getProblemTotal()
                ));
                // 更新
                if (checkIsExist(hxQualityProblem)) {
                    hxQualityProblemMapper.updateSelective(hxQualityProblem);
                }
                // 新增
                else {
                    hxQualityProblemMapper.insertSelective(hxQualityProblem);
                }

            }
        });
    }

    private boolean checkIsExist(HxQualityProblem hxQualityProblem) {
        return hxQualityProblemMapper.checkIsExist(hxQualityProblem) > 0;
    }
}
