package com.ailanyin.admin.service.impl;

import com.ailanyin.admin.service.HxTodayDynamicService;
import com.ailanyin.common.utils.BigDecimalUtil;
import com.ailanyin.common.utils.EmptyUtil;
import com.ailanyin.mapper.HxTodayDynamicMapper;
import com.ailanyin.model.HxTodayDynamic;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.List;

/**
 * @author ailanyin
 * @version 1.0
 * @since 2021/12/8 0008 上午 11:30
 */
@Service
public class HxTodayDynamicServiceImpl implements HxTodayDynamicService {

    @Resource
    private HxTodayDynamicMapper hxTodayDynamicMapper;

    /**
     * 今日动态列表
     *
     * @param hxTodayDynamic hxTodayDynamic
     * @return list
     */
    @Override
    public List<HxTodayDynamic> selectHxTodayDynamicList(HxTodayDynamic hxTodayDynamic) {
        return hxTodayDynamicMapper.selectHxTodayDynamicList(hxTodayDynamic);
    }

    @Override
    public void importData(List<HxTodayDynamic> list) {
        list.forEach(this::handleData);
    }


    /**
     * 数据库操作 不存在新增，存在更新
     */
    @Transactional(rollbackFor = Exception.class)
    public void handleData(HxTodayDynamic hxTodayDynamic) {
        if (EmptyUtil.isNotEmpty(hxTodayDynamic.getTodayDate())) {
            setRate(hxTodayDynamic);
            // 存在  更新
            if (checkTodayDynamicIsExist(hxTodayDynamic.getTodayDate())) {
                hxTodayDynamicMapper.updateByTodayDateSelective(hxTodayDynamic);
            }
            // 不存在  新增
            else {
                hxTodayDynamicMapper.insertSelective(hxTodayDynamic);
            }
        }
    }

    /**
     * 检查某天动态是否已经存在
     *
     * @param todayDate 日期
     * @return 是/否
     */
    private boolean checkTodayDynamicIsExist(String todayDate) {
        return hxTodayDynamicMapper.checkTodayDynamicIsExist(todayDate) > 0;
    }

    private void setRate(HxTodayDynamic hxTodayDynamic) {
        // 计算完成率
        hxTodayDynamic.setTaskRate(BigDecimalUtil.calculateCompletionRate(
                hxTodayDynamic.getCompleteTask(),
                hxTodayDynamic.getTotalTask()
        ));
        hxTodayDynamic.setWorkerRate(BigDecimalUtil.calculateCompletionRate(
                hxTodayDynamic.getAttendanceWorker(),
                hxTodayDynamic.getTotalWorker()
        ));
        hxTodayDynamic.setEquipmentRate(BigDecimalUtil.calculateCompletionRate(
                hxTodayDynamic.getOperatingEquipment(),
                hxTodayDynamic.getTotalEquipment()
        ));
    }
}
