package com.ailanyin.admin.service.impl;

import com.ailanyin.admin.service.SysBlacklistUserService;
import com.ailanyin.common.constant.UserConstants;
import com.ailanyin.common.service.RedisService;
import com.ailanyin.common.utils.EmptyUtil;
import com.ailanyin.common.utils.IpUtil;
import com.ailanyin.mapper.SysBlacklistUserMapper;
import com.ailanyin.model.SysBlacklistUser;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * @author ailanyin
 * @version 1.0
 * @since 2021/11/1 0001 下午 15:14
 */
@Service
public class SysBlacklistUserServiceImpl implements SysBlacklistUserService {

    @Autowired
    private RedisService redisService;
    @Resource
    private SysBlacklistUserMapper blacklistUserMapper;
    @Value("${redis.database}")
    private String database;

    /**
     * 获取黑名单列表
     *
     * @param blacklistUser blacklistUser
     * @return list
     */
    @Override
    public List<SysBlacklistUser> selectBlackList(SysBlacklistUser blacklistUser) {
        return blacklistUserMapper.selectByParam(blacklistUser);
    }

    /**
     * 批量删除日志
     *
     * @param ids ids
     */
    @Override
    public void removeBlacklistUser(List<SysBlacklistUser> ids) {
        List<String> idList = new ArrayList<>();
        List<String> ipList = new ArrayList<>();
        ids.forEach(
                blacklistUser -> {
                    idList.add(blacklistUser.getId());
                    ipList.add(blacklistUser.getIp());
                }
        );
        blacklistUserMapper.deleteBatchIds(idList);
        // 从缓存中移除
        redisService.sRemove(database + UserConstants.BLACKLIST_KEY, ipList.toArray());
    }

    /**
     * 新增黑名单
     *
     * @param blacklistUser blacklistUser
     */
    @Override
    public void insertBlacklistUser(SysBlacklistUser blacklistUser) {
        if (EmptyUtil.isNotEmpty(blacklistUser.getIp())) {
            blacklistUser.setAddress(IpUtil.getRealAddressByIp(blacklistUser.getIp()));
        }
        blacklistUser.setCreateTime(new Date());
        blacklistUserMapper.insertBlacklistUser(blacklistUser);
    }
}
