package com.ailanyin.common.utils;


import com.alibaba.fastjson.JSON;
import com.aliyuncs.DefaultAcsClient;
import com.aliyuncs.IAcsClient;
import com.aliyuncs.dysmsapi.model.v20170525.SendSmsRequest;
import com.aliyuncs.dysmsapi.model.v20170525.SendSmsResponse;
import com.aliyuncs.exceptions.ClientException;
import com.aliyuncs.profile.DefaultProfile;
import com.aliyuncs.profile.IClientProfile;
import com.tencentcloudapi.common.Credential;
import com.tencentcloudapi.common.exception.TencentCloudSDKException;
import com.tencentcloudapi.common.profile.ClientProfile;
import com.tencentcloudapi.common.profile.HttpProfile;
import com.tencentcloudapi.sms.v20210111.SmsClient;


/**
 * 短信工具类
 *
 * @author ailanyin
 * @version 1.0
 * @since 2021/11/16 0016 上午 9:47
 */
public class SmsUtil {

    /**
     * 阿里云-accessKeyId
     */
    private static final String ALIYUN_ACCESSKEY_ID = "=============";
    /**
     * 阿里云-accessKeySecret
     */
    private static final String ALIYUN_ACCESSKEY_SECRET = "=============";
    /**
     * 阿里云-短信签名
     */
    private static final String ALIYUN_SIGN_NAME = "=============";
    /**
     * 阿里云-短信模板
     */
    private static final String ALIYUN_TEMPLATE_CODE = "=============";
    /**
     * 阿里云-短信发送成功
     */
    private static final String ALIYUN_SEND_OK = "OK";

    /**
     * 腾讯云-accessKeyId
     */
    private static final String TENCENTYUN_ACCESSKEY_ID = "=============";
    /**
     * 腾讯云-accessKeySecret
     */
    private static final String TENCENTYUN_ACCESSKEY_SECRET = "=============";
    /**
     * 腾讯云-短信应用ID
     */
    private static final String TENCENTYUN_SDK_APP_ID = "=============";
    /**
     * 腾讯云-短信签名
     */
    private static final String TENCENTYUN_SIGN_NAME = "=============";
    /**
     * 腾讯云-短信模板
     */
    private static final String TENCENTYUN_TEMPLATE_ID = "=============";

    /**
     * 发送腾讯云短信
     *
     * @param phoneNumberSet phoneList
     * @param templateParamSet 模板
     */
    public static void sendTencentYunMsg(String[] phoneNumberSet, String[] templateParamSet) {
        try {

            Credential cred = new Credential(TENCENTYUN_ACCESSKEY_ID, TENCENTYUN_ACCESSKEY_SECRET);
            // 实例化一个http选项，可选，没有特殊需求可以跳过
            HttpProfile httpProfile = new HttpProfile();
            // 设置请求方式
            httpProfile.setReqMethod("POST");
            /* SDK有默认的超时时间，非必要请不要进行调整
             * 如有需要请在代码中查阅以获取最新的默认值 */
            httpProfile.setConnTimeout(60);
            /* SDK会自动指定域名。通常是不需要特地指定域名的，但是如果你访问的是金融区的服务
             * 则必须手动指定域名，例如sms的上海金融区域名： sms.ap-shanghai-fsi.tencentcloudapi.com */
            httpProfile.setEndpoint("sms.tencentcloudapi.com");
            /* 非必要步骤:
             * 实例化一个客户端配置对象，可以指定超时时间等配置 */
            ClientProfile clientProfile = new ClientProfile();
            /* SDK默认用TC3-HMAC-SHA256进行签名
             * 非必要请不要修改这个字段 */
            clientProfile.setSignMethod("HmacSHA256");
            clientProfile.setHttpProfile(httpProfile);
            /* 实例化要请求产品(以sms为例)的client对象
             * 第二个参数是地域信息，可以直接填写字符串ap-guangzhou，或者引用预设的常量 */
            SmsClient client = new SmsClient(cred, "ap-guangzhou", clientProfile);
            /* 实例化一个请求对象，根据调用的接口和实际情况，可以进一步设置请求参数
             * 你可以直接查询SDK源码确定接口有哪些属性可以设置
             * 属性可能是基本类型，也可能引用了另一个数据结构
             * 推荐使用IDE进行开发，可以方便的跳转查阅各个接口和数据结构的文档说明 */
            com.tencentcloudapi.sms.v20210111.models.SendSmsRequest req = new com.tencentcloudapi.sms.v20210111.models.SendSmsRequest();

            /* 填充请求参数,这里request对象的成员变量即对应接口的入参
             * 你可以通过官网接口文档或跳转到request对象的定义处查看请求参数的定义
             * 基本类型的设置:
             * 帮助链接：
             * 短信控制台: https://console.cloud.tencent.com/smsv2
             * sms helper: https://cloud.tencent.com/document/product/382/3773 */

            /* 短信应用ID: 短信SdkAppId在 [短信控制台] 添加应用后生成的实际SdkAppId，示例如1400006666 */
            req.setSmsSdkAppId(TENCENTYUN_SDK_APP_ID);

            /* 短信签名内容: 使用 UTF-8 编码，必须填写已审核通过的签名，签名信息可登录 [短信控制台] 查看 */
            req.setSignName(TENCENTYUN_SIGN_NAME);

            /* 国际/港澳台短信 SenderId: 国内短信填空，默认未开通，如需开通请联系 [sms helper] */
            String senderid = "";
            req.setSenderId(senderid);

            /* 用户的 session 内容: 可以携带用户侧 ID 等上下文信息，server 会原样返回 */
            String sessionContext = "xxx";
            req.setSessionContext(sessionContext);

            /* 短信号码扩展号: 默认未开通，如需开通请联系 [sms helper] */
            String extendCode = "";
            req.setExtendCode(extendCode);

            /* 模板 ID: 必须填写已审核通过的模板 ID。模板ID可登录 [短信控制台] 查看 */
            req.setTemplateId(TENCENTYUN_TEMPLATE_ID);

            /* 下发手机号码，采用 E.164 标准，+[国家或地区码][手机号]
             * 示例如：+8613711112222， 其中前面有一个+号 ，86为国家码，13711112222为手机号，最多不要超过200个手机号 */
            req.setPhoneNumberSet(phoneNumberSet);

            /* 模板参数: 若无模板参数，则设置为空 */
            req.setTemplateParamSet(templateParamSet);

            /* 通过 client 对象调用 SendSms 方法发起请求。注意请求方法名与请求对象是对应的
             * 返回的 res 是一个 SendSmsResponse 类的实例，与请求对象对应 */
            com.tencentcloudapi.sms.v20210111.models.SendSmsResponse res = client.SendSms(req);

            // 输出json格式的字符串回包
            System.out.println(JSON.toJSONString(res));

            // 也可以取出单个值，你可以通过官网接口文档或跳转到response对象的定义处查看返回字段的定义
            System.out.println(res.getRequestId());

        } catch (TencentCloudSDKException e) {
            e.printStackTrace();
        }
    }

    /**
     * 发送阿里云短信验证码
     *
     * @param phone   目标手机号
     * @param msgCode 验证码
     */
    public static void sendAliYunMsg(String phone, String msgCode) {
        try {
            //设置超时时间-可自行调整
            System.setProperty("sun.net.client.defaultConnectTimeout", "10000");
            System.setProperty("sun.net.client.defaultReadTimeout", "10000");
            //初始化ascClient,暂时不支持多region（请勿修改）
            IClientProfile profile = DefaultProfile.getProfile("cn-hangzhou", ALIYUN_ACCESSKEY_ID, ALIYUN_ACCESSKEY_SECRET);
            IAcsClient acsClient = new DefaultAcsClient(profile);
            //组装请求对象
            SendSmsRequest request = new SendSmsRequest();
            //必填:待发送手机号。支持以逗号分隔的形式进行批量调用，批量上限为1000个手机号码,批量调用相对于单条调用及时性稍有延迟,验证码类型的短信推荐使用单条调用的方式；发送国际/港澳台消息时，接收号码格式为00+国际区号+号码，如“0085200000000”
            request.setPhoneNumbers(phone);
            //必填:短信签名-可在短信控制台中找到***************************
            request.setSignName(ALIYUN_SIGN_NAME);
            //必填:短信模板-可在短信控制台中找到，发送国际/港澳台消息时，请使用国际/港澳台短信模版**************************
            request.setTemplateCode(ALIYUN_TEMPLATE_CODE);
            //可选:模板中的变量替换JSON串,如模板内容为"亲爱的${name},您的验证码为${code}"时,此处的值为
            //友情提示:如果JSON中需要带换行符,请参照标准的JSON协议对换行符的要求,比如短信内容中包含\r\n的情况在JSON中需要表示成\\r\\n,否则会导致JSON在服务端解析失败
            request.setTemplateParam("{\"code\":\"" + msgCode + "\"}");
            //请求失败这里会抛ClientException异常
            SendSmsResponse sendSmsResponse = acsClient.getAcsResponse(request);
            if (sendSmsResponse.getCode() == null || !ALIYUN_SEND_OK.equals(sendSmsResponse.getCode())) {
                System.out.println(phone + "=====fail====");
            }
        } catch (ClientException e) {
            e.printStackTrace();
        }

    }

}
